@@ -16,7 +16,7 @@ oebuild_git_params = {
     "envsetup": "poky/oe-init-build-env",
     "distro": "poky",
     "machine": "dragonboard-845c",
-    "target": "core-image-minimal",
+    "targets": ["core-image-minimal"],
     "bblayers_conf": ['BBLAYERS += "../meta-qcom/"'],
     "environment": {},
     "local_manifest": "tests/unit/test.xml",
@@ -132,7 +132,7 @@ oebuild_repo_object = {
     "envsetup": "poky/oe-init-build-env",
     "distro": "poky",
     "machine": "dragonboard-845c",
-    "target": "core-image-minimal",
+    "targets": ["core-image-minimal"],
     "local_conf": [
         'PREFERRED_PROVIDER_virtual/kernel = "linux-generic-mainline"',
         'PREFERRED_VERSION_linux-generic-mainline = "git%"',
