@@ -1,10 +1,5 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
-# vim: set ts=4
-#
-# Copyright 2021-present Linaro Limited
-#
-# SPDX-License-Identifier: MIT
 
 import sys
 import json
@@ -12,7 +7,6 @@ import json
 from tuxbake.models import OEBuild
 from tuxbake.argparse import setup_parser
 from tuxbake.build import build
-from tuxmake.runtime import Terminated
 from tuxbake.exceptions import (
     TuxbakeParsingError,
     TuxbakeRunCmdError,
@@ -28,9 +22,14 @@ def main() -> int:
     with open(options.build_definition) as reader:
         try:
             build_definition = json.load(reader)
+            legacy_target = build_definition.get("target")
+            targets = build_definition.get("targets")
+            if legacy_target:
+                if targets is None:
+                    build_definition["targets"] = [legacy_target]
+                del build_definition["target"]
             OEBuild.validate(build_definition)
             build(
-                # **(json.load(reader)),
                 **(build_definition),
                 src_dir=options.src_dir,
                 build_dir=options.build_dir_name,
@@ -42,8 +41,6 @@ def main() -> int:
                 build_only=options.build_only,
                 sync_only=options.sync_only,
             )
-        except (KeyboardInterrupt, Terminated) as ex:
-            print("tuxbake Interrupted")
         except (TuxbakeParsingError, TuxbakeRunCmdError) as ex:
             sys.stderr.write(f"{str(ex)}\n")
             sys.exit(1)
