@@ -1,5 +1,6 @@
 import os
 import subprocess
+from pathlib import Path
 from tuxbake.exceptions import TuxbakeRunCmdError
 
 
@@ -23,16 +24,23 @@ def repo_init(oebuild, src_dir, local_manifest=None, pinned_manifest=None):
 
 def git_init(oebuild, src_dir):
     for git_object in oebuild.git_trees:
-        url = git_object.url
+        url = git_object.url.rstrip("/")
         branch = git_object.branch
         ref = git_object.ref
         sha = git_object.sha
         basename = os.path.splitext(os.path.basename(url))[0]
-        if branch:
-            cmd = f"git clone {url} -b {branch}".split()
+        dir_repo = Path(os.path.join(src_dir, basename))
+        if dir_repo.exists() and dir_repo.is_dir():
+            cmd = f"git fetch origin".split()
+            run_cmd(cmd, os.path.join(src_dir, basename))
+            cmd = f"git checkout -B {branch} origin/{branch}".split()
+            run_cmd(cmd, os.path.join(src_dir, basename))
         else:
-            cmd = f"git clone {url}".split()
-        run_cmd(cmd, src_dir)
+            if branch:
+                cmd = f"git clone {url} -b {branch}".split()
+            else:
+                cmd = f"git clone {url}".split()
+            run_cmd(cmd, src_dir)
         if ref:
             cmd = f"git fetch origin {ref}:{ref}-local".split()
             run_cmd(cmd, f"{src_dir}/{basename}")
@@ -44,6 +52,7 @@ def git_init(oebuild, src_dir):
 
 
 def run_cmd(cmd, src_dir, env=None, fail_ok=False):
+    print(f"Running cmd: '{cmd}' in '{src_dir}'")
     process = subprocess.Popen(cmd, cwd=src_dir, env=env)
     process.communicate()
     if not fail_ok and process.returncode != 0:
